/* -*- mode: c++; c-basic-offset: 3; -*- */
#ifndef HTML_GENATTR_HH
#define HTML_GENATTR_HH

#include "html/Attrib.hh"
#include <string>

namespace html {
   class writer;

   /**  The Generic attribute class allows specification of attributes that 
     *  may have a string value.
     *  @memo Generic attribute class
     *  @author John Zweizig
     *  @version 1.1; Last modified August 23, 2005
     *  @ingroup IO_html
     */
   class genAttr : public attrib {
   public:
      /** Construct an initialized generic attribute.
        *  \brief Value constructor.
	*  \param value Attribute value.
	*/
      genAttr(const std::string& value);

      /** Destructor.
        */
      virtual ~genAttr(void);

      /**  Clone a generic attribute object.
        *  @memo Clone a genAttr.
        *  \return Cloned attribute instance.
        */
      virtual genAttr* clone(void) const;

      /**  Append an attribute to the current value separated by a single
        *  separator character.
	*  \brief   Append an attribut string to this.
	*  \param x Attribute instance to be appended to this.
	*  \param sep separator. 
	*/
      virtual void append(const attrib& x, int sep=' ');

      /**  Test whether the default value is specified. The default value of 
        *  the generic attribute is assumed to be the null string.
	*  @memo Test for default value.
	*  @return true if the return value is the default.
	*/
      virtual bool isDefault(void) const;

      /**  Test whether this attribute has a value specified. This method is 
        *  supplies the virtual metod of the attrib API and is always true.
	*  @memo Test for attribute with a value.
	*  @return true for genAttr
	*/
      virtual bool hasArg(void) const;

      /**  Set the attribute to the specified string value.
        *  \brief Set the attribute value. 
	*  \param value String to which the value will bw set.
	*/
      virtual void setValue(const std::string& value);

      /**  Return the attribute value as a string.
       *   \brief Attribute value string.
       *   \return the value string.
       */
      virtual std::string valString(void) const;
 
      /**  Compare the attribute with another generic attribute.
        *  \brief Compare the attribute  to a nother.
	*  \param x Attribute instance to which this will bw compared
	*  \return True if the attribute values are equal.
	*/
      bool operator==(const genAttr& x) const;

   private:
      std::string mValue;
   };

   //===================================  Inline methods.
   inline std::string
   genAttr::valString(void) const {
      return mValue;
   }
}

#endif //  HTML_GENATTR_HH
