/* -*- mode: c++; c-basic-offset: 4; -*- */
#ifndef HTML_TEXTATTR_HH
#define HTML_TEXTATTR_HH

#include "Attrib.hh"

namespace html {
    class color;
    class size;
    class font;

    /**  @memo Text data attribute API
      *  The textAttr class holds the text attributes.
      *  @author J. Zweizig
      *  @version "$Header$"
      *  @ingroup IO_html
      */
    class textAttr : public attList {
    public:
	/**  Construct a text attribute list.
	  *  @brief Constructor.
	  */
	textAttr(void);

	/**  Destroy a text attribute list.
	  *  @brief destructor.
	  */
	virtual ~textAttr(void) {}

	/**  Get the color attribute.
	  *  @brief Get the color.
	  *  @return Color attribute.
	  */
	const color& getColor(void) const;

	/**  Get the font type attribute.
	  *  @brief Get the font.
	  *  @return Font attribute.
	  */
	const font&  getFont(void) const;

	/**  Get the font size attribute.
	  *  @brief Get the font size.
	  *  @return Size sttributue
	  */
	const size&  getSize(void) const;

	/** get a test-format style string.
	 */
        std::string getTextStyle(void) const; 

	/**  Add an arbitrary test attribute. Non-text attributes will result
	  *  in an error? The attribute name is set to match the attribute class
	  *  and may or may not be meaningful.
	  *  \brief Set a text attribute.
	  *  \param set a text attribute
	  */
	void setAttr(const attrib& att);

	/**  Set the font face attribute.
	  *  @brief Set the font attribute
	  *  @param x New font attribute
	  */
	void setFont(const font& x);

	/**  Set the text color attribute.
	  *  @brief Set the color attribute
	  *  @param x New color attribute
	  */
	void setColor(const color& x);

	/**  Set the size attribute.
	  *  @brief set the size attribute
	  *  @param x new size attribute
	  */
	void setSize(const size& x);

	/**  Merge specified attribute list with the current attributes.
	  *  @brief Merge attribute lists.
	  *  @param x Attribute list to be merged.
	  */
	void merge(const textAttr& x);

	/**  Merge specified attribute list with the current attributes.
	  *  @brief Merge attribute lists.
	  *  @param x Attribute list to be merged.
	  */
	void merge(const attList& x) {
	    attList::merge (x); }

	/**  Remove any attributes in a specified list.
	  *  @brief Suppress specified attributes.
	  *  @param x List of attributes to be suppressed.
	  */
	void suppress(const textAttr& x);
    };

}
#endif  //  HTML_TEXTATTR_HH
